ewa.clisupport

Package ewa :: Module clisupport |
[hide private]
[frames] | no frames]

# Module clisupport

source code

Version: 0.62.6.1

Classes | [hide private]
| DeleteFinder
| RecursiveMp3FileIterator
| RecursiveChangedMp3FileIterator

Functions | [hide private]
get_serve_parser() | source code
get_splice_parser() | source code
get_ap_parser() | source code
resolve_engine(enginename) | source code
do_splice(args) | source code
do_audioprovider(args) | source code
_find_config(givenpath) | source code
do_serve(args) | source code
_change_user_group() | source code
run_server(func, pidfile=None, daemonize=True) | source code

Variables | [hide private]
| have_unix = `1`
| haveflup = `False`
| havepaste = `False`
| VERSION_TEXT = ``'``%s 0.62.6.1\n\nCopyright (C) 2007, 2010 WNYC N``...``
| SERVE_DESCRIPTION = ``'``Starts a WSGI application that produces c``...``
| RULE_DESCRIPTION = ``'``Produces a combined MP3 file according to` `...``
| SPLICE_DESCRIPTION = ``'``Splices MP3 files together.\n``'``
| __package__ = ``'``ewa``'``

Variables Details | [hide private]

  ### VERSION_TEXT Value:
      '''%s 0.62.6.1

      Copyright (C) 2007, 2010 WNYC New York Public Radio.
      This is free software; see the source for copying conditions.  There i
      s NO
      warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PUR
      POSE.

      ...

  ### SERVE_DESCRIPTION Value:
      '''Starts a WSGI application that produces combined MP3 files
      according to the specified rules.
      '''

  ### RULE_DESCRIPTION Value:
      '''Produces a combined MP3 file according to the specified rules.
      '''